==> datarouter-bytes-0.0.108-sources.jar: io/datarouter/bytes/binarydto/fieldcodec/other/EnumBinaryDtoFieldCodec.java <==
/*
 * Copyright © 2009 HotPads (admin@hotpads.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.datarouter.bytes.binarydto.fieldcodec.other;

import io.datarouter.bytes.LengthAndValue;
import io.datarouter.bytes.binarydto.fieldcodec.BinaryDtoBaseFieldCodec;
import io.datarouter.bytes.codec.stringcodec.TerminatedStringCodec;

public class EnumBinaryDtoFieldCodec<E extends Enum<E>> extends BinaryDtoBaseFieldCodec<E>{

	private static final TerminatedStringCodec CODEC = TerminatedStringCodec.US_ASCII;

	private final Class<E> type;

	public EnumBinaryDtoFieldCodec(Class<E> type){
		this.type = type;
	}

	@Override
	public byte[] encode(E value){
		return CODEC.encode(value.name());
	}

	@Override
	public E decode(byte[] bytes, int offset){
		return decodeWithLength(bytes, offset).value;
	}

	@Override
	public LengthAndValue<E> decodeWithLength(byte[] bytes, int offset){
		LengthAndValue<String> stringLengthAndValue = CODEC.decode(bytes, offset);
		int length = stringLengthAndValue.length;
		E value = Enum.valueOf(type, stringLengthAndValue.value);
		return new LengthAndValue<>(length, value);
	}

	@Override
	public int compareAsIfEncoded(E left, E right){
		return left.name().compareTo(right.name());
	}

}

==> datarouter-bytes-0.0.114-sources.jar: io/datarouter/bytes/binarydto/fieldcodec/other/EnumBinaryDtoFieldCodec.java <==
/*
 * Copyright © 2009 HotPads (admin@hotpads.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.datarouter.bytes.binarydto.fieldcodec.other;

import io.datarouter.bytes.binarydto.fieldcodec.BinaryDtoBaseFieldCodec;
import io.datarouter.bytes.codec.stringcodec.StringCodec;

public class EnumBinaryDtoFieldCodec<E extends Enum<E>> extends BinaryDtoBaseFieldCodec<E>{

	private static final StringCodec CODEC = StringCodec.US_ASCII;

	private final Class<E> type;

	public EnumBinaryDtoFieldCodec(Class<E> type){
		this.type = type;
	}

	@Override
	public boolean supportsComparableCodec(){
		return true;
	}

	@Override
	public byte[] encode(E value){
		return CODEC.encode(value.name());
	}

	@Override
	public E decode(byte[] bytes, int offset, int length){
		String stringValue = CODEC.decode(bytes, offset, length);
		return Enum.valueOf(type, stringValue);
	}

	@Override
	public int compareAsIfEncoded(E left, E right){
		return left.name().compareTo(right.name());
	}

}
